[Freeswitch-svn] [commit] r8266 - in freeswitch/trunk/scripts/contrib: trixter verifier/EventSocket/trunk/EventWatcher verifier/EventSocket/trunk/FreeSwitchEventSocket verifier/EventSocket/trunk/FreeSwitchEventSocket/SipEvents

Freeswitch SVN mikej at freeswitch.org
Mon May 5 17:27:12 EDT 2008


Author: mikej
Date: Mon May  5 17:27:11 2008
New Revision: 8266

Modified:
   freeswitch/trunk/scripts/contrib/trixter/call-progress.pl
   freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/EventWatcher/CallManager.cs
   freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/ChannelInfo.cs
   freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/SipEvents/EventPresence.cs

Log:
fix in tree scripts to match changed state names. (FSCORE-119)

Modified: freeswitch/trunk/scripts/contrib/trixter/call-progress.pl
==============================================================================
--- freeswitch/trunk/scripts/contrib/trixter/call-progress.pl	(original)
+++ freeswitch/trunk/scripts/contrib/trixter/call-progress.pl	Mon May  5 17:27:11 2008
@@ -138,7 +138,7 @@
 	    } elsif (watchedChannel($myhash->{'channel-name'})) {
           if ($myhash->{'event-name'} eq "CHANNEL_ANSWER") {   ## deal with answers
             do_answer($myhash);
-          } elsif ($myhash->{'event-name'} eq "CHANNEL_STATE" && $myhash->{'channel-state'} eq "CS_RING") {
+          } elsif ($myhash->{'event-name'} eq "CHANNEL_STATE" && $myhash->{'channel-state'} eq "CS_ROUTING") {
             do_ring($myhash);
           } elsif ($myhash->{'event-name'} eq "CHANNEL_HANGUP") { ## last thing done on a channel
             do_hangup($myhash);

Modified: freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/EventWatcher/CallManager.cs
==============================================================================
--- freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/EventWatcher/CallManager.cs	(original)
+++ freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/EventWatcher/CallManager.cs	Mon May  5 17:27:11 2008
@@ -60,7 +60,7 @@
             if (theEvent is EventPresenceIn)
             {
                 EventPresenceIn ep = (EventPresenceIn) theEvent;
-                //Channel-State: CS_RING
+                //Channel-State: CS_ROUTING
                 //Channel-Name: sofia/default/jonas%40192.168.1.102%3A5070
                 //Unique-ID: 2f87ba27-2f71-d64d-8c64-9966ee894eac
                 //Call-Direction: inbound
@@ -68,7 +68,7 @@
                 //Event-Name: PRESENCE_IN
                 CallState state = CallState.Unknown;
                 string destination = string.Empty;
-                if (ep.ChannelState.ChannelInfo.State == ChannelState.Ring)
+                if (ep.ChannelState.ChannelInfo.State == ChannelState.Routing)
                 {
                     if (IsInbound(ep))
                     {

Modified: freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/ChannelInfo.cs
==============================================================================
--- freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/SipEvents/EventPresence.cs	(original)
+++ freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/SipEvents/EventPresence.cs	Mon May  5 17:27:11 2008
@@ -34,7 +34,7 @@
         }
 
         /// <summary>
-        /// Caller is only specified on state CS_RING
+        /// Caller is only specified on state CS_ROUTING
         /// and not on CS_HANGUP
         /// </summary>
         public PartyInfo Caller



More information about the Freeswitch-svn mailing list
--- freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/ChannelInfo.cs	(original)
+++ freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/ChannelInfo.cs	Mon May  5 17:27:11 2008
@@ -3,16 +3,16 @@
     #region enum ChannelState
     public enum ChannelState
     {
-        New,       // Channel is newly created 
-        Init,      // Channel has been initilized
-        Ring,      // Channel is looking for a dialplan
-        Transmit,  // Channel is in a passive transmit state
-        Execute,   // Channel is executing it's dialplan 
-        Loopback,  // Channel is in loopback
-        Hold,	  // Channel is on hold
-        Hibernate, // Channel is in a sleep state
-        Hangup,    // Channel is flagged for hangup and ready to end
-        Done,      // Channel is ready to be destroyed and out of the state machine
+        New,           // Channel is newly created 
+        Init,          // Channel has been initilized
+        Routing,       // Channel is looking for a dialplan
+        SoftExecute    // Channel is in a passive transmit state
+        Execute,       // Channel is executing it's dialplan 
+        ExchangeMedia, // Channel is exchanging media
+        ConsumeMedia,  // Channel is consuming media
+        Hibernate,     // Channel is in a sleep state
+        Hangup,        // Channel is flagged for hangup and ready to end
+        Done,          // Channel is ready to be destroyed and out of the state machine
         Unknown
     }
     #endregion
@@ -205,11 +205,11 @@
             {
                 case "CS_NEW": return ChannelState.New;
                 case "CS_INIT": return ChannelState.Init;
-                case "CS_RING": return ChannelState.Ring;
-                case "CS_TRANSMIT": return ChannelState.Transmit;
+                case "CS_ROUTING": return ChannelState.Routing;
+                case "CS_SOFT_EXECUTE": return ChannelState.SoftExecute;
                 case "CS_EXECUTE": return ChannelState.Execute;
-                case "CS_LOOPBACK": return ChannelState.Loopback;
-                case "CS_HOLD": return ChannelState.Hold;
+                case "CS_EXCHANGE_MEDIA": return ChannelState.ExchangeMedia;
+                case "CS_CONSUME_MEDIA": return ChannelState.ConsumeMedia;
                 case "CS_HIBERNATE": return ChannelState.Hibernate;
                 case "CS_HANGUP": return ChannelState.Hangup;
                 case "CS_DONE": return ChannelState.Done;

Modified: freeswitch/trunk/scripts/contrib/verifier/EventSocket/trunk/FreeSwitchEventSocket/SipEvents/EventPresence.cs
==============================================================================